<?php
/**
 * @file
 * 
 * Contains the administrative callback handlers
 */

/**
 * Implements the callback for the petfinder_admin_form
 */
function petfinder_admin_form($form, &$form_state) {
  $cfg = _petfinder_get_cfg();
  $dev_url = 'http://www.petfinder.com/developers';

  // Prompt text at top of form
  $form['help_prompt'] = array(
    '#markup' => t(
      'Please fill in the following information in order to enable !pf integration.',
      array(
        '!pf' => '<strong>Petfinder.com</strong>',
      )
    ),
    '#prefix' => '<div><p>',
    '#suffix' => '</p></div>',
  );
  $form['help_more_info'] = array(
    '#markup' => t(
      'The API and Secret keys may be obtained by setting up a developer account at !url',
      array(
        '!url' => l($dev_url, $dev_url, array('attributes' => array('target' => '_blank'))),
      )
    ),
    '#prefix' => '<div><p>',
    '#suffix' => '</p></div>',
  );

  // Form input elements
  $form['api_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Petfinder API key'),
    '#default_value' => (!empty($cfg['api_key'])) ? $cfg['api_key'] : '',
    '#required' => TRUE,
  );
  $form['secret_key'] = array(
    '#type' => 'textfield',
    '#title' => t('Petfinder API secret'),
    '#default_value' => (!empty($cfg['secret_key'])) ? $cfg['secret_key'] : '',
    '#required' => TRUE,
  );
  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Save settings'),
  );
  
  return $form;
}

/**
 * Implements the form validation callback for petfinder_admin_form 
 */
function petfinder_admin_form_validate($form, &$form_state) {
  $values = $form_state['values'];

  // Create a dummy Petfinder session to test the keys provided
  $pf = new PetfinderSession();
  $retval = $pf->init($values['api_key'], $values['secret_key']);
  if (!$retval) {
    form_set_error('keys_validation', t('The provided API key + secret combination is invalid, unable to create a signed test connection.  Please check your values and try again.'));
  }
}

/**
 * Implements the form submit callback for petfinder_admin_form 
 */
function petfinder_admin_form_submit($form, &$form_state) {
  $values = $form_state['values'];
  _petfinder_set_cfg($values);
  drupal_set_message(t('Petfinder settings successfully saved'));
}

